plfp library

Support for doing something awesome.

More dartdocs go here.

Classes

Either<L, R>
A union type that represents either a Left or a Right.
Lazy<T>
Represents a value that is computed lazily.
Optional<T>
The optional value.
Result<S, F>
A result type that can be either a success or a failure.
ServiceStore

Exceptions / Errors

ResultException<F>
ServiceStoreException